@@ -405,7 +405,6 @@ class fMMS_Viewer(hildon.Program):
 		attachments = self.cont.get_mms_attachments(filename)
 		selector = hildon.TouchSelector(text=True)
 		for fn in attachments:
-			print fn
 			selector.append_text(fn)
 
 		selector.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_MULTIPLE)
@@ -417,6 +416,7 @@ class fMMS_Viewer(hildon.Program):
 
 		diag = gtk.Dialog()
 		diag.set_title(self.saveattachments)
+		diag.set_transient_for(self.window)
 		diag.vbox.add(pan)
 		diag.set_size_request(-1, 320)
 		diag.add_button(gtk.STOCK_SAVE, gtk.RESPONSE_APPLY)
@@ -431,6 +431,7 @@ class fMMS_Viewer(hildon.Program):
 	def choose_your_destiny(self, src, attachments, current_text, current_count):
 		current_text = current_text.replace('(', '').replace(')','')
 		fcd = hildon.FileChooserDialog(self.window, action=gtk.FILE_CHOOSER_ACTION_SAVE)
+		fcd.set_transient_for(self.window)
 		if os.path.isdir("/home/user/MyDocs/"):
 			fcd.set_current_folder("/home/user/MyDocs/")
 		fcd.set_default_response(gtk.RESPONSE_OK)
@@ -466,6 +467,8 @@ class fMMS_Viewer(hildon.Program):
 		if not os.path.isfile(dst):
 			log.info("copying %s -> %s" % (src, dst))
 			shutil.copy(src, dst)
+			banner = hildon.hildon_banner_show_information(self.window, "", \
+					gettext.ldgettext('hildon-libs', "wdgt_bd_done"))
 		else:
 			log.info("copy failed: file exists (%s -> %s)" % (src, dst))
 			banner = hildon.hildon_banner_show_information(self.window, "", \
